@@ -2,7 +2,7 @@
 //!
 //! # Usage
 //!
-//! ```
+//! ```rust
 //! fn main() {
 //!     println!("{}", meddl_translate::translate("Hallo"));
 //! }
@@ -11,10 +11,24 @@
 //! # Examples
 //!
 //! ```shell
-//! $ cargo run --example hallo
+//! $ cargo run --example hello
 //! ```
 //! ```shell
-//! $ cargo run --example langer-text
+//! $ cargo run --example long-text
+//! ```
+//!
+//! # Excluding words from being translation
+//!
+//! ```json
+//! "ignored": [
+//!     "den"
+//! ]
+//! ```
+//!
+//! Example containing an ignored word:
+//!
+//! ```shell
+//! $ cargo run --example ignored
 //! ```
 //!
 //! # Benchmark
@@ -25,9 +39,15 @@
 //!
 //! You need to use Rust nightly for running the benchmark.
 
+mod util;
+
 use serde_json::Value;
 use regex::Regex;
 use rand::Rng;
+use util::{is_ignored_word, get_random_index};
+use std::env;
+
+const INTERLUDE_RANDOM_NUMBER: i16 = 225;
 
 fn parse_translation() -> Option<Value> {
     let translation_string = include_str!("de-oger.json");
@@ -60,9 +80,10 @@ pub fn translate(original: &str) -> String {
 
         let translated_punctuation = translate_punctuation(&punctuation, &translation);
         let translated_word = translate_word(&word_no_punctuation, &translation);
+        let translated_word_with_interlude: String = add_interlude(&translated_word, &translation);
 
-        meddl.push_str(&translated_word);
-        meddl.push_str(translated_punctuation);
+        meddl.push_str(&translated_word_with_interlude);
+        meddl.push_str(&translated_punctuation);
         meddl.push(' ');
     }
 
@@ -72,17 +93,21 @@ pub fn translate(original: &str) -> String {
 fn translate_word<'a>(word: &'a str, translation: &'a Value) -> String {
     let word = translate_quotation_marks(word, translation);
 
-    if let Some(_key) = translation["translations"].get(&word) {
-      let possible_translations = translation["translations"][&word]
-          .as_array()
-          .unwrap();
-      let length = possible_translations.len();
-      let random = rand::thread_rng().gen_range(0..length);
+    if is_ignored_word(&word, &translation["ignored"]) {
+        return word;
+    }
 
-      let translated_word = possible_translations[random]
-          .as_str()
-          .unwrap_or(&word);
-      return String::from(translated_word);
+    if let Some(_key) = translation["translations"].get(&word) {
+        let possible_translations = translation["translations"][&word]
+            .as_array()
+            .unwrap();
+        let length = possible_translations.len();
+        let random = rand::thread_rng().gen_range(0..length);
+
+        let translated_word = possible_translations[random]
+            .as_str()
+            .unwrap_or(&word);
+        return String::from(translated_word);
     } else {
         /* !!!
            "twistedChars" is an object that contains the char combinations that
@@ -101,7 +126,7 @@ fn translate_word<'a>(word: &'a str, translation: &'a Value) -> String {
                 let translated_word = word
                     .replace(charset, array.1
                         .as_str()
-                        .unwrap()
+                        .unwrap(),
                     );
                 return translated_word;
             }
@@ -110,7 +135,7 @@ fn translate_word<'a>(word: &'a str, translation: &'a Value) -> String {
     String::from(&word)
 }
 
-fn translate_punctuation<'a>(punctuation: &'a str, translation: &'a Value) -> &'a str {
+fn translate_punctuation<'a>(punctuation: &'a str, translation: &'a Value) -> String {
     return match punctuation {
         "." => {
             let dot_pool = translation["dot"]
@@ -121,8 +146,8 @@ fn translate_punctuation<'a>(punctuation: &'a str, translation: &'a Value) -> &'
                 .as_str()
                 .unwrap();
 
-            translated_dot
-        },
+            String::from(translated_dot)
+        }
         "!" => {
             let exclamation_mark_pool = translation["exclamationMark"]
                 .as_array()
@@ -132,8 +157,8 @@ fn translate_punctuation<'a>(punctuation: &'a str, translation: &'a Value) -> &'
                 .as_str()
                 .unwrap();
 
-            translated_exclamation_mark
-        },
+            String::from(translated_exclamation_mark)
+        }
         "?" => {
             let question_mark_pool = translation["questionMark"]
                 .as_array()
@@ -143,10 +168,10 @@ fn translate_punctuation<'a>(punctuation: &'a str, translation: &'a Value) -> &'
                 .as_str()
                 .unwrap();
 
-            translated_question_mark
+            String::from(translated_question_mark)
         }
-        _ => punctuation
-    }
+        _ => String::from(punctuation)
+    };
 }
 
 fn translate_quotation_marks(word: &str, translation: &Value) -> String {
@@ -154,12 +179,32 @@ fn translate_quotation_marks(word: &str, translation: &Value) -> String {
         return word.replacen("\"", translation["quotationMark"]
             .as_str()
             .unwrap(),
-        1);
+                             1);
     }
     String::from(word)
 }
 
-fn get_random_index(vec: &Vec<Value>) -> usize {
-    let len = vec.len();
-    rand::thread_rng().gen_range(0..len)
+fn add_interlude(word_to_add_to: &str, translation: &Value) -> String {
+    if let Ok(_value) = env::var("MEDDl_TRANSLATE_INTERLUDE_SET") {
+        return String::from(word_to_add_to);
+    }
+
+    let interlude = translation["interlude"]
+        .as_str()
+        .unwrap();
+
+    let ran = rand::thread_rng().gen_range(0..INTERLUDE_RANDOM_NUMBER);
+
+    return if ran < 2 {
+        let word_with_interlude = format!(
+            "{}{}",
+            word_to_add_to,
+            interlude
+        );
+        env::set_var("MEDDl_TRANSLATE_INTERLUDE_SET", "true");
+
+        word_with_interlude
+    } else {
+        String::from(word_to_add_to)
+    };
 }
\ No newline at end of file
